##  Introduction
The integration supports the mapping of relations between fact sheets in SAP LeanIX to relations between assets in Collibra. This enhances data governance and lineage tracking, enabling better management of dependencies, impacts, and relationships between assets.
The following relations are supported:
  * relApplicationToDataObject:
Map relations between applications and data objects of the conceptual data layer from SAP LeanIX to Collibra.
  * relInterfaceToDataObject:
Map relations between interfaces and data objects of the conceptual data layer from SAP LeanIX to Collibra.
![Mapping of Relation Between Application/Interface and Data Object](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d386e7a441014b6d3bbca9727b051_LowRes.png)
Mapping of Relation Between Application/Interface and Data Object
    * relApplicationToBusinessCapability:
Map relations between applications and business capabilities from SAP LeanIX to Collibra.
![Mapping of Relation Between Application and Business Capability](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2752feed7a4410149befebbb14c9ce10_LowRes.png)
Mapping of Relation Between Application and Business Capability
      * relConsumerApplicationToInterface:
Map relations between consumer applications and interfaces from SAP LeanIX to Collibra.
      * relProviderApplicationToInterface:
Map relations between provider applications and interfaces from SAP LeanIX to Collibra.
![Mapping of Relation Between Application and Interface](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274add907a4410148689db5e6f04ff52_LowRes.png)
Mapping of Relation Between Application and Interface
